==> zio-aws-backup_2.12-5.17.129.2-sources.jar: zio/aws/backup/model/UpdateRegionSettingsRequest.scala <==
package zio.aws.backup.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.backup.model.primitives.{IsEnabled, ResourceType}
import scala.jdk.CollectionConverters._
final case class UpdateRegionSettingsRequest(
    resourceTypeOptInPreference: Option[Map[ResourceType, IsEnabled]] = None,
    resourceTypeManagementPreference: Option[Map[ResourceType, IsEnabled]] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.backup.model.UpdateRegionSettingsRequest = {
    import UpdateRegionSettingsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.backup.model.UpdateRegionSettingsRequest
      .builder()
      .optionallyWith(
        resourceTypeOptInPreference.map(value =>
          value
            .map({ case (key, value) =>
              (ResourceType.unwrap(key): java.lang.String) -> (IsEnabled
                .unwrap(value): java.lang.Boolean)
            })
            .asJava
        )
      )(_.resourceTypeOptInPreference)
      .optionallyWith(
        resourceTypeManagementPreference.map(value =>
          value
            .map({ case (key, value) =>
              (ResourceType.unwrap(key): java.lang.String) -> (IsEnabled
                .unwrap(value): java.lang.Boolean)
            })
            .asJava
        )
      )(_.resourceTypeManagementPreference)
      .build()
  }
  def asReadOnly: zio.aws.backup.model.UpdateRegionSettingsRequest.ReadOnly =
    zio.aws.backup.model.UpdateRegionSettingsRequest.wrap(buildAwsValue())
}
object UpdateRegionSettingsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.backup.model.UpdateRegionSettingsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.backup.model.UpdateRegionSettingsRequest =
      zio.aws.backup.model.UpdateRegionSettingsRequest(
        resourceTypeOptInPreference.map(value => value),
        resourceTypeManagementPreference.map(value => value)
      )
    def resourceTypeOptInPreference: Option[Map[ResourceType, IsEnabled]]
    def resourceTypeManagementPreference: Option[Map[ResourceType, IsEnabled]]
    def getResourceTypeOptInPreference
        : ZIO[Any, AwsError, Map[ResourceType, IsEnabled]] =
      AwsError.unwrapOptionField(
        "resourceTypeOptInPreference",
        resourceTypeOptInPreference
      )
    def getResourceTypeManagementPreference
        : ZIO[Any, AwsError, Map[ResourceType, IsEnabled]] =
      AwsError.unwrapOptionField(
        "resourceTypeManagementPreference",
        resourceTypeManagementPreference
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.backup.model.UpdateRegionSettingsRequest
  ) extends zio.aws.backup.model.UpdateRegionSettingsRequest.ReadOnly {
    override val resourceTypeOptInPreference
        : Option[Map[ResourceType, IsEnabled]] = scala
      .Option(impl.resourceTypeOptInPreference())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.backup.model.primitives.ResourceType(
              key
            ) -> zio.aws.backup.model.primitives.IsEnabled(value)
          })
          .toMap
      )
    override val resourceTypeManagementPreference
        : Option[Map[ResourceType, IsEnabled]] = scala
      .Option(impl.resourceTypeManagementPreference())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.backup.model.primitives.ResourceType(
              key
            ) -> zio.aws.backup.model.primitives.IsEnabled(value)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.backup.model.UpdateRegionSettingsRequest
  ): zio.aws.backup.model.UpdateRegionSettingsRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-backup_2.13-5.17.203.2-sources.jar: zio/aws/backup/model/UpdateRegionSettingsRequest.scala <==
package zio.aws.backup.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.backup.model.primitives.{IsEnabled, ResourceType}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateRegionSettingsRequest(
    resourceTypeOptInPreference: Optional[Map[ResourceType, IsEnabled]] =
      Optional.Absent,
    resourceTypeManagementPreference: Optional[Map[ResourceType, IsEnabled]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.backup.model.UpdateRegionSettingsRequest = {
    import UpdateRegionSettingsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.backup.model.UpdateRegionSettingsRequest
      .builder()
      .optionallyWith(
        resourceTypeOptInPreference.map(value =>
          value
            .map({ case (key, value) =>
              (ResourceType.unwrap(key): java.lang.String) -> (IsEnabled
                .unwrap(value): java.lang.Boolean)
            })
            .asJava
        )
      )(_.resourceTypeOptInPreference)
      .optionallyWith(
        resourceTypeManagementPreference.map(value =>
          value
            .map({ case (key, value) =>
              (ResourceType.unwrap(key): java.lang.String) -> (IsEnabled
                .unwrap(value): java.lang.Boolean)
            })
            .asJava
        )
      )(_.resourceTypeManagementPreference)
      .build()
  }
  def asReadOnly: zio.aws.backup.model.UpdateRegionSettingsRequest.ReadOnly =
    zio.aws.backup.model.UpdateRegionSettingsRequest.wrap(buildAwsValue())
}
object UpdateRegionSettingsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.backup.model.UpdateRegionSettingsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.backup.model.UpdateRegionSettingsRequest =
      zio.aws.backup.model.UpdateRegionSettingsRequest(
        resourceTypeOptInPreference.map(value => value),
        resourceTypeManagementPreference.map(value => value)
      )
    def resourceTypeOptInPreference: Optional[Map[ResourceType, IsEnabled]]
    def resourceTypeManagementPreference: Optional[Map[ResourceType, IsEnabled]]
    def getResourceTypeOptInPreference
        : ZIO[Any, AwsError, Map[ResourceType, IsEnabled]] =
      AwsError.unwrapOptionField(
        "resourceTypeOptInPreference",
        resourceTypeOptInPreference
      )
    def getResourceTypeManagementPreference
        : ZIO[Any, AwsError, Map[ResourceType, IsEnabled]] =
      AwsError.unwrapOptionField(
        "resourceTypeManagementPreference",
        resourceTypeManagementPreference
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.backup.model.UpdateRegionSettingsRequest
  ) extends zio.aws.backup.model.UpdateRegionSettingsRequest.ReadOnly {
    override val resourceTypeOptInPreference
        : Optional[Map[ResourceType, IsEnabled]] = zio.aws.core.internal
      .optionalFromNullable(impl.resourceTypeOptInPreference())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.backup.model.primitives.ResourceType(
              key
            ) -> zio.aws.backup.model.primitives.IsEnabled(value)
          })
          .toMap
      )
    override val resourceTypeManagementPreference
        : Optional[Map[ResourceType, IsEnabled]] = zio.aws.core.internal
      .optionalFromNullable(impl.resourceTypeManagementPreference())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.backup.model.primitives.ResourceType(
              key
            ) -> zio.aws.backup.model.primitives.IsEnabled(value)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.backup.model.UpdateRegionSettingsRequest
  ): zio.aws.backup.model.UpdateRegionSettingsRequest.ReadOnly = new Wrapper(
    impl
  )
}
